function [numberOfNodes, procsPerNode, numberOfMpiProcs, memParam, gpuParam, lsParam] = getCommonSelectParams(cluster, procsPerNode, environmentProperties)

assert(cluster.NumThreads<=procsPerNode, ...
       'ProcsPerNode (%d) must be greater than or equal to cluster.NumThreads (%d).', ...
       procsPerNode, cluster.NumThreads)

if cluster.NumThreads==procsPerNode
    numberOfNodes = environmentProperties.NumberOfTasks;
else
    % PPN > THREADS
    if environmentProperties.NumberOfTasks*cluster.NumThreads<=procsPerNode
        numberOfNodes = 1; procsPerNode = environmentProperties.NumberOfTasks*cluster.NumThreads;
    else
        % WORKERS*THREADS > PPN
        assert(mod(procsPerNode,cluster.NumThreads)==0, ...
               'ProcsPerNode (%d) must be multiple of cluster.NumThreads (%d).', ...
               procsPerNode, cluster.NumThreads)
        assert(mod(environmentProperties.NumberOfTasks*cluster.NumThreads,procsPerNode)==0, ...
               'NumberOfTasks (%d) and cluster.NumThreads (%d) must be multiple of ProcsPerNode (%d).', ...
               environmentProperties.NumberOfTasks, cluster.NumThreads, procsPerNode)

        numberOfNodes = environmentProperties.NumberOfTasks*cluster.NumThreads/procsPerNode;
    end
end

numberOfMpiProcs = procsPerNode/cluster.NumThreads;

% Maximum amount of memory used by a chunk
mu = validatedPropValue(cluster, 'MemPerCPU', 'char', '4gb');
if ~isempty(mu)
    memParam = sprintf(':mem=%s', mu);
else
    memParam = '';
end

% Check if the user requested a GPU
ngpus = validatedPropValue(cluster, 'GPUsPerNode', 'double', 0);
if ngpus>0
    gpuParam = sprintf(':ngpus=%d:Qlist=ee', ngpus);
else
    gpuParam = '';
end

% Check if the user requested a large scratch
use_ls = validatedPropValue(cluster, 'UseLargeScratch', 'boolean', false);
if use_ls
    lsParam = ':large-scratch=true';
else
    lsParam = '';
end

end
